@@ -19,6 +19,16 @@ def get_registry():
     return celery_app.conf["PYRAMID_REGISTRY"]
 
 
+def get_request():
+    """
+    Return the Pyramid application request associated to the current running
+    application context
+    """
+    from pyramid_celery import celery_app
+
+    return celery_app.conf["PYRAMID_REQUEST"]
+
+
 def get_setting(key, mandatory=False, default=None):
     """
     Collect a given setting
