@@ -49,7 +49,7 @@ class Job(DBBASE, PersistentACLMixin):
         "polymorphic_on": "type_",
         "polymorphic_identity": "job",
     }
-    label = u"Tâche générique"
+    label = "Tâche générique"
     id = Column(
         Integer,
         primary_key=True,
@@ -108,13 +108,13 @@ class Job(DBBASE, PersistentACLMixin):
         result = True
         if self.status in ("planned", "running"):
             if datetime.now() - self.updated_at > TIMEOUT:
-                self.status = u"failed"
+                self.status = "failed"
                 if hasattr(self, "error_messages"):
                     self.error_messages = [
-                        u"Cette tâche a été automatiquement annulée car elle "
-                        u"n'a pas pu être traitée. Veulliez contacter un "
-                        u"administrateur en lui fournissant l'identifiant de "
-                        u"tâche suivant : {0}".format(self.id)
+                        "Cette tâche a été automatiquement annulée car elle "
+                        "n'a pas pu être traitée. Veulliez contacter un "
+                        "administrateur en lui fournissant l'identifiant de "
+                        "tâche suivant : {0}".format(self.id)
                     ]
                 result = False
         return result
@@ -133,7 +133,7 @@ class CsvImportJob(Job):
     error_messages = Column(JsonEncodedList, default=None)
     in_error_csv = Column(Text(), default=None)
     unhandled_datas_csv = Column(Text(), default=None)
-    label = u"Import de données"
+    label = "Import de données"
 
     def is_not_void_str(self, value):
         """
@@ -162,7 +162,7 @@ class MailingJob(Job):
     id = Column(Integer, ForeignKey("job.id"), primary_key=True)
     messages = Column(JsonEncodedList, default=None)
     error_messages = Column(JsonEncodedList, default=None)
-    label = u"Envoi de mail"
+    label = "Envoi de mail"
 
     def todict(self):
         res = Job.todict(self)
@@ -179,7 +179,7 @@ class FileGenerationJob(Job):
     id = Column(Integer, ForeignKey("job.id"), primary_key=True)
     filename = Column(Text)
     error_messages = Column(JsonEncodedList, default=None)
-    label = u"Génération de fichier"
+    label = "Génération de fichier"
 
     def todict(self):
         res = Job.todict(self)
