@@ -2,17 +2,25 @@
 Tasks used to compile treasury measures
 """
 import datetime
+from abc import ABC, abstractmethod
+from typing import List, Optional, Type, Tuple
 import transaction
 
 from dateutil.relativedelta import relativedelta
 
 from pyramid_celery import celery_app
-from sqlalchemy import or_, desc
+from sqlalchemy import or_, desc, func
 from collections import OrderedDict
 from datetime import date
 
 from endi_base.models.base import DBSESSION
 from endi_base.mail import send_mail
+from endi.models.accounting.base import (
+    BaseAccountingMeasure,
+    BaseAccountingMeasureGrid,
+    BaseAccountingMeasureType,
+    BaseAccountingMeasureTypeCategory,
+)
 from endi.models.accounting.operations import (
     AccountingOperationUpload,
     AccountingOperation,
@@ -25,6 +33,7 @@ from endi.models.accounting.treasury_measures import (
 )
 from endi_celery.conf import (
     get_recipients_addresses,
+    get_request,
 )
 from endi.models.accounting.income_statement_measures import (
     IncomeStatementMeasure,
@@ -32,10 +41,19 @@ from endi.models.accounting.income_statement_measures import (
     IncomeStatementMeasureType,
     IncomeStatementMeasureTypeCategory,
 )
+from endi.models.accounting.balance_sheet_measures import (
+    BalanceSheetMeasure,
+    BalanceSheetMeasureType,
+    BalanceSheetMeasureGrid,
+    ActiveBalanceSheetMeasureType,
+    PassiveBalanceSheetMeasureType,
+)
+
 from endi.models.accounting.accounting_closures import (
     AccountingClosure,
 )
-from endi.models.config import get_config
+from endi.models.config import Config
+from endi_celery.locks import acquire_lock, is_locked, release_lock
 
 from endi_celery.tasks import utils
 
@@ -43,10 +61,6 @@ from endi_celery.tasks import utils
 logger = utils.get_logger(__name__)
 
 
-class KnownError(Exception):
-    pass
-
-
 class GridCacheItem:
     """
     Wraps a grid in cache and provide storages for
@@ -161,7 +175,7 @@ class GridCache:
         return self._datas.get(key)
 
 
-class BaseMeasureCompiler(object):
+class BaseMeasureCompiler(ABC):
     """
     Base measure compiler
 
@@ -177,10 +191,11 @@ class BaseMeasureCompiler(object):
     (not related to account numbers)
     """
 
-    measure_type_class = None
-    measure_type_category_class = None
-    measure_grid_class = None
-    measure_class = None
+    measure_type_class: BaseAccountingMeasureType
+    measure_type_category_class: Optional[BaseAccountingMeasureTypeCategory]
+    measure_grid_class: BaseAccountingMeasureGrid
+    measure_class: BaseAccountingMeasure
+    label: str
 
     def __init__(self, upload, operations):
         self.upload = upload
@@ -195,7 +210,7 @@ class BaseMeasureCompiler(object):
         self.computed_measure_types = self._collect_computed_measure_types()
 
         self.all_type_ids = [t.id for t in self.common_measure_types]
-        for cat_id, types in self.computed_measure_types.items():
+        for types in self.computed_measure_types.values():
             self.all_type_ids.extend([t.id for t in types])
 
         self.processed_grids = []
@@ -205,12 +220,17 @@ class BaseMeasureCompiler(object):
         Build a query to list active measure types
         :returns: An sqlalchemy query object
         """
-        return (
-            self.measure_type_class.query()
-            .join(self.measure_type_category_class)
-            .filter(self.measure_type_class.active == True)  # noqa: E712
-            .filter(self.measure_type_category_class.active == True)  # noqa: E712
-        )
+        if self.measure_type_category_class:
+            return (
+                self.measure_type_class.query()
+                .join(self.measure_type_category_class)
+                .filter(self.measure_type_class.active == True)  # noqa: E712
+                .filter(self.measure_type_category_class.active == True)  # noqa: E712
+            )
+        else:
+            return self.measure_type_class.query().filter(
+                self.measure_type_class.active == True
+            )  # noqa: E712
 
     def _collect_common_measure_types(self):
         """
@@ -228,11 +248,14 @@ class BaseMeasureCompiler(object):
             .all()
         )
 
-    def _collect_categories(self):
+    def _collect_categories(self) -> Optional[List[BaseAccountingMeasureTypeCategory]]:
         """
         Retrieve all measure type categories
         """
-        return self.measure_type_category_class.get_categories()
+        if self.measure_type_category_class:
+            return self.measure_type_category_class.get_categories()
+        else:
+            return None
 
     def _collect_computed_measure_types(self):
         """
@@ -242,18 +265,32 @@ class BaseMeasureCompiler(object):
         """
         result = OrderedDict()
         query = self._get_active_type_query()
-        query = (
-            query.filter(
-                self.measure_type_class.is_total == True,  # noqa: E712
+
+        if self.measure_type_category_class:
+            query = (
+                query.filter(
+                    self.measure_type_class.is_total == True,  # noqa: E712
+                )
+                .filter(
+                    self.measure_type_class.total_type != "account_prefix",
+                )
+                .order_by(self.measure_type_category_class.order)
+                .order_by(self.measure_type_class.order)
             )
-            .filter(
-                self.measure_type_class.total_type != "account_prefix",
+        else:
+            query = (
+                query.filter(
+                    self.measure_type_class.is_total == True,  # noqa: E712
+                )
+                .filter(
+                    self.measure_type_class.total_type != "account_prefix",
+                )
+                .order_by(self.measure_type_class.order)
             )
-            .order_by(self.measure_type_category_class.order)
-            .order_by(self.measure_type_class.order)
-        )
+
         for typ in query:
             result.setdefault(typ.category_id, []).append(typ)
+
         return result
 
     def get_cache_key_from_grid(self, grid):
@@ -288,6 +325,7 @@ class BaseMeasureCompiler(object):
         self.session.flush()
         return measure
 
+    @abstractmethod
     def _clean_existing_grid(self, grid_item):
         """
         Clean an existing grid on first load
@@ -297,6 +335,14 @@ class BaseMeasureCompiler(object):
         """
         pass
 
+    @abstractmethod
+    def _query_grid(self, operation):
+        pass
+
+    @abstractmethod
+    def _get_new_grid(self, operation):
+        pass
+
     def get_grid_item(self, operation):
         """
         Retrieve the grid related to the given operation datas
@@ -325,13 +371,14 @@ class BaseMeasureCompiler(object):
         :param obj grid_item: An instance of GridCacheItem
         """
         result = {}
-        for category in self.categories:
-            result[category.label] = grid_item.get_category_total(category.id)
+        if self.categories:
+            for category in self.categories:
+                result[category.label] = grid_item.get_category_total(category.id)
 
         for typ_ in self.common_measure_types:
             result[typ_.label] = grid_item.get_type_total(typ_.id)
 
-        for typlist_ in self.computed_measure_types.values():
+        for typlist_ in list(self.computed_measure_types.values()):
             for typ_ in typlist_:
                 value = grid_item.get_type_total(typ_.id)
                 result[typ_.label] = value
@@ -343,7 +390,7 @@ class BaseMeasureCompiler(object):
         Cache all grid totals in order to use them in computation
         """
         for grid_item in self.processed_grids:
-            for measure in grid_item.get_measures().values():
+            for measure in list(grid_item.get_measures().values()):
                 grid_item.set_total_type(measure)
                 grid_item.update_category_total(measure)
 
@@ -367,7 +414,6 @@ class BaseMeasureCompiler(object):
             measures = current_grid_item.get_measures()
 
             for measure_type in self.common_measure_types:
-                matched = False
                 if measure_type.match(operation.general_account):
                     measure = measures.get(measure_type.id)
                     if measure is None:
@@ -380,9 +426,7 @@ class BaseMeasureCompiler(object):
                     operation_sign = measure_type.sign()
 
                     measure.value += operation_sign * operation.total()
-                    matched = True
 
-                if matched:
                     self.session.merge(measure)
                     self.session.flush()
 
@@ -414,7 +458,7 @@ class BaseMeasureCompiler(object):
         """
         for grid_item in self.processed_grids:
             measures = grid_item.get_measures()
-            for category_id, measure_types in self.computed_measure_types.items():
+            for category_id, measure_types in list(self.computed_measure_types.items()):
                 for measure_type in measure_types:
                     values = self.get_values_for_computation(grid_item)
                     value = measure_type.compute_total(values)
@@ -446,6 +490,194 @@ class BaseMeasureCompiler(object):
         self.session.flush()
         return [griditem.grid for griditem in self.processed_grids]
 
+    def _get_date_to_use_for_grid(self):
+        date_to_use = self.upload.updated_at.date()
+        this_year = datetime.datetime.today().year
+
+        # If synchronized accounting and écritures from last year
+        if (
+            self.upload.filetype == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
+            and self.upload.date.year < this_year
+        ):
+            # Only works for 31/12 exercice closure, not a problem as long as
+            # synchronized accounting works year by year
+            date_to_use = datetime.date(day=31, month=12, year=self.upload.date.year)
+
+        return date_to_use
+
+
+class BalanceSheetMeasureCompiler(BaseMeasureCompiler):
+    measure_type_class = BalanceSheetMeasureType
+    measure_type_category_class = None
+    measure_grid_class = BalanceSheetMeasureGrid
+    measure_class = BalanceSheetMeasure
+    label = "Génération des bilans"
+
+    def get_message(self, grids):
+        return """Génération des bilans
+
+Bilans générés : {}
+
+----
+enDI
+""".format(
+            len(grids)
+        )
+
+    def get_cache_key_from_operation(self, operation):
+        """
+        Build a cache key based on the given operation object
+        """
+        date_to_use = self._get_date_to_use_for_grid()
+        key = (operation.company_id, date_to_use)
+
+        return key
+
+    def get_cache_key_from_grid(self, grid):
+        """
+        Build a cache key based on the given grid object
+        """
+        key = (grid.company_id, grid.date)
+        return key
+
+    def _query_grid(self, operation):
+        """
+        Query a grid associated to the given operation
+
+        Query filters should match the get_cache_key_from_operation options
+        """
+        date_to_use = self._get_date_to_use_for_grid()
+        query = (
+            BalanceSheetMeasureGrid.query()
+            .filter_by(date=date_to_use)
+            .filter_by(company_id=operation.company_id)
+        )
+
+        query = query.order_by(desc(BalanceSheetMeasureGrid.datetime))
+        return query.first()
+
+    def _get_new_grid(self, operation):
+        """
+        Build a new grid based on the given operation
+
+        :param obj operation: The AccountingOperation from which we build
+        measure
+        """
+        date_to_use = self._get_date_to_use_for_grid()
+        return BalanceSheetMeasureGrid(
+            date=date_to_use,
+            company_id=operation.company_id,
+            upload=self.upload,
+        )
+
+    def _clean_existing_grid(self, grid_item):
+        """
+        Clean an existing grid on first load
+
+        :param obj grid_item: A GridCacheItem instance
+        """
+        for measure in grid_item.grid.measures:
+            self.session.delete(measure)
+
+    def _process_computed_measures(self):
+        for grid_item in self.processed_grids:
+            measures = grid_item.get_measures()
+            for category_id, measure_types in list(self.computed_measure_types.items()):
+                for measure_type in measure_types:
+                    if measure_type.total_type == "complex_total":
+                        values = self._get_values_for_computation(grid_item)
+                        value = measure_type.compute_total(values)
+                        measure = measures.get(measure_type.id)
+
+                    if measure_type.total_type == "categories":
+                        # Total of passive and active (not necessarily meaningfull
+                        # in real life)
+                        if (
+                            measure_type.account_prefix == "active,passive"
+                            or measure_type.account_prefix == "passive,active"
+                        ):
+                            value = self._get_balance_sheet_passive_active_total_value(
+                                grid_item, measure_type
+                            )
+                        elif isinstance(measure_type, ActiveBalanceSheetMeasureType):
+                            value = self._get_balance_sheet_total_value(grid_item, True)
+                        elif isinstance(measure_type, PassiveBalanceSheetMeasureType):
+                            value = self._get_balance_sheet_total_value(
+                                grid_item, False
+                            )
+                        else:
+                            raise Exception(
+                                "Unexpected measure type (passive or active expected)"
+                            )
+
+                    measure = measures.get(measure_type.id)
+                    if measure is None:
+                        measure = self._get_new_measure(
+                            measure_type,
+                            grid_item.grid.id,
+                        )
+                        grid_item.store_measure(measure)
+                    else:
+                        measure.order = measure_type.order
+
+                    measure.value = measure_type.sign() * value
+                    self.session.merge(measure)
+                    grid_item.set_total_type(measure)
+
+        return self.processed_grids
+
+    def _get_values_for_computation(self, grid_item):
+        """
+        Collect total values in a dict for complex datas computation
+
+        :param obj grid_item: An instance of GridCacheItem
+        """
+        result = {}
+        result["Total Actif"] = self._get_balance_sheet_total_value(grid_item, True)
+        result["Total Passif"] = self._get_balance_sheet_total_value(grid_item, False)
+
+        for typ_ in self.common_measure_types:
+            result[typ_.label] = grid_item.get_type_total(typ_.id)
+
+        for typlist_ in list(self.computed_measure_types.values()):
+            for typ_ in typlist_:
+                value = grid_item.get_type_total(typ_.id)
+                result[typ_.label] = value
+
+        return result
+
+    def _get_balance_sheet_total_value(self, grid_item, active):
+        if active:
+            polymorphic_id = "active_balance_sheet"
+        else:
+            polymorphic_id = "passive_balance_sheet"
+
+        query = (
+            self.session.query(func.sum(BalanceSheetMeasure.value))
+            .filter(BalanceSheetMeasure.grid_id == grid_item.grid.id)
+            .outerjoin(BalanceSheetMeasure.measure_type)
+            .filter(BalanceSheetMeasureType.type_ == polymorphic_id)
+            .filter(BalanceSheetMeasureType.is_total == False)
+        )
+
+        if query.first() and query.first()[0] is not None:
+            return query.first()[0]
+        else:
+            return 0
+
+    def _get_balance_sheet_passive_active_total_value(self, grid_item, measure_type):
+        query = (
+            self.session.query(func.sum(BalanceSheetMeasure.value))
+            .filter(BalanceSheetMeasure.grid_id == grid_item.grid.id)
+            .outerjoin(BalanceSheetMeasure.measure_type)
+            .filter(BalanceSheetMeasureType.is_total == False)
+        )
+
+        if query.first() and query.first()[0] is not None:
+            return query.first()[0]
+        else:
+            return 0
+
 
 class TreasuryMeasureCompiler(BaseMeasureCompiler):
     measure_type_class = TreasuryMeasureType
@@ -465,21 +697,6 @@ enDI
             len(grids)
         )
 
-    def _get_date_to_use_for_grid(self):
-        date_to_use = self.upload.updated_at.date()
-        this_year = datetime.datetime.today().year
-
-        # If synchronized accounting and écritures from last year
-        if (
-            self.upload.filetype == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING
-            and self.upload.date.year < this_year
-        ):
-            # Only works for 31/12 exercice closure, not a problem as long as
-            # synchronized accounting works year by year
-            date_to_use = datetime.date(day=31, month=12, year=self.upload.date.year)
-
-        return date_to_use
-
     def get_cache_key_from_operation(self, operation):
         """
         Build a cache key based on the given operation object
@@ -611,13 +828,11 @@ enDI
         setting the updated_at attribute
         """
         logger.debug(
-            u"  + Processing specific datas for child {}".format(
-                self.__class__.__name__
-            )
+            "  + Processing specific datas for child {}".format(self.__class__.__name__)
         )
 
         # Calling parent to really process measures
-        logger.debug("Calling parent process common measures")
+        logger.debug("  + Calling parent process common measures")
         BaseMeasureCompiler._process_common_measures(self)
 
         # Choosing which date has to be used
@@ -637,27 +852,21 @@ enDI
         return self.processed_grids
 
 
-def get_measure_compilers(data_type, grid_type=None):
-    """
-    Retrieve the measure compilers to be used with this given type of datas
+GRID_COMPILERS = {
+    "treasury": TreasuryMeasureCompiler,
+    "income_statement": IncomeStatementMeasureCompiler,
+    "balance_sheet": BalanceSheetMeasureCompiler,
+}
 
-    :param str data_type: The type of data we build our measures from
-    :returns: The measure compiler
+
+def get_measure_compilers(grid_type=None) -> List[Type[BaseMeasureCompiler]]:
     """
-    if data_type == AccountingOperationUpload.ANALYTICAL_BALANCE:
-        logger.info("  + Handling analytical_balance file")
-        return [TreasuryMeasureCompiler]
-    elif data_type == AccountingOperationUpload.GENERAL_LEDGER:
-        logger.info("  + Handling General Ledger file")
-        return [TreasuryMeasureCompiler, IncomeStatementMeasureCompiler]
-    elif data_type == AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
-        logger.info("  + Handling Synchronized Datas")
-        if grid_type == "treasury":
-            return [TreasuryMeasureCompiler]
-        elif grid_type == "income_statement":
-            return [IncomeStatementMeasureCompiler]
-        else:
-            return [TreasuryMeasureCompiler, IncomeStatementMeasureCompiler]
+    Retrieve the measure compilers to be used
+    """
+    if grid_type is not None:
+        return [GRID_COMPILERS[grid_type]]
+    else:
+        return list(GRID_COMPILERS.values())
 
 
 MAIL_ERROR_SUBJECT = "[Erreur] {}"
@@ -696,28 +905,10 @@ def send_error(request, mail_addresses, type_label, message):
             logger.exception("Error sending email")
 
 
-def get_closure_day_and_month():
-    # Get config from main app
-    config = get_config()
-
-    closure_day = 0
-    closure_month = 0
-    if (
-        config.get("accounting_closure_day") is not None
-        and config.get("accounting_closure_month") is not None
-    ):
-        closure_day = int("0" + str(config.get("accounting_closure_day")))
-        closure_month = int("0" + str(config.get("accounting_closure_month")))
-
-    # If days and month not set, assume that closure is at the end of the year
-    if closure_day == 0 or closure_month == 0:
-        logger.info(
-            u"Accounting closure day or month not set, assuming closure\
-                is on 31/12"
-        )
-        closure_day = 31
-        closure_month = 12
-
+def get_closure_day_and_month() -> Tuple[int, int]:
+    # Get data from endi's configuration
+    closure_day = Config.get_value("accounting_closure_day", default=31, type_=int)
+    closure_month = Config.get_value("accounting_closure_month", default=12, type_=int)
     return closure_day, closure_month
 
 
@@ -727,7 +918,6 @@ def get_current_exercice_dates(upload_date):
     """
     # Reference year for collecting data
     current_year = upload_date.year
-
     closure_day, closure_month = get_closure_day_and_month()
 
     # Find exercice begining day and month
@@ -782,8 +972,7 @@ def get_current_exercice_dates(upload_date):
             )
 
     logger.info(
-        "Current exercice start the {} and ends the\
-            {}".format(
+        "  + Current exercice starts the {} and ends the {}".format(
             current_exercice_begining_date, current_exercice_end_date
         )
     )
@@ -791,7 +980,9 @@ def get_current_exercice_dates(upload_date):
     return current_exercice_begining_date, current_exercice_end_date
 
 
-def _collect_operations(upload_id, data_type, upload_date):
+def collect_operations_by_fiscal_year(
+    upload_id: int, data_type: str, upload_date: datetime.date
+) -> List[AccountingOperation]:
     """
     Return the operations needed.
     Collect the operations ("écritures") according to the "exercice fiscal".
@@ -801,28 +992,30 @@ def _collect_operations(upload_id, data_type, upload_date):
     For now, this function is only for the treasury meausures, in the future
     it might also be for the income statement measure.
     """
-    logger.debug(u"Collecting operations for {} upload".format(upload_id))
+    logger.debug("  + Collecting operations for upload : {}".format(upload_id))
 
     (
         current_exercice_begining_date,
         current_exercice_end_date,
     ) = get_current_exercice_dates(upload_date)
 
+    # Pour la tréso on ne prend pas les écritures dans le futur
+    # ATTENTION : Pour l'instant _collect_operations() n'est que pour la tréso
+    # mais si elle est utilisé pour d'autres états il faudra filtrer ici
+    max_operation_date = min(current_exercice_end_date, date.today())
+
     current_exercice_operations = (
         AccountingOperation.query()
         .filter(
             AccountingOperation.date.between(
-                current_exercice_begining_date, current_exercice_end_date
+                current_exercice_begining_date, max_operation_date
             )
         )
         .all()
     )
 
     logger.debug(
-        u"{} operations\
-            collected".format(
-            len(current_exercice_operations)
-        )
+        "    + {} operations collected".format(len(current_exercice_operations))
     )
 
     # Adding last exercice operations if needed
@@ -839,7 +1032,7 @@ def _collect_operations(upload_id, data_type, upload_date):
     if former_year_closure:
         closure_is_done = former_year_closure.active
 
-    logger.info(u"{} closure is done : {}".format(former_closure_year, closure_is_done))
+    logger.info(f"    + {former_closure_year} closure is done ?: {closure_is_done}")
 
     if not closure_is_done:
         last_exercice_begining_date = current_exercice_begining_date - relativedelta(
@@ -858,8 +1051,7 @@ def _collect_operations(upload_id, data_type, upload_date):
         )
 
         logger.info(
-            u"Appending {} operations from last\
-                exercice".format(
+            "    + Appending {} operations from last exercice".format(
                 len(last_exercice_operations)
             )
         )
@@ -869,13 +1061,109 @@ def _collect_operations(upload_id, data_type, upload_date):
     return current_exercice_operations
 
 
-def get_upload_from_id(upload_id):
+def collect_operations(
+    compiler_type: str, upload: AccountingOperationUpload
+) -> List[AccountingOperation]:
+    """collect operations to use for the given compiler_type
+
+    :param grid_type: _description_
+    :type grid_type: str
+    :param upload: _description_
+    :type upload: AccountingOperationUpload
+    :return: _description_
+    :rtype: List[AccountingOperation]
+    """
+    if compiler_type != "treasury":
+        return AccountingOperation.query().filter_by(upload_id=upload.id)
+    else:
+        return collect_operations_by_fiscal_year(
+            upload.id, upload.filetype, upload.date
+        )
+
+
+def run_compiler(compiler_type: str, upload_id: int):
+    """
+    Collect accounting operations to be used by the compiler factory
+    """
+    logger.info(
+        f"# Compiling {compiler_type} for AccoutingOperationUpload : {upload_id}"
+    )
+    request = get_request()
+    mail_addresses = get_recipients_addresses(request)
+    messages = []
+    transaction.begin()
     upload = AccountingOperationUpload.get(upload_id)
     if upload is None:
-        raise Exception(
-            "No AccountingOperationUpload instance with id {}".format(upload_id)
+        logger.error("  - Upload doesn't exist")
+        transaction.abort()
+        return False
+
+    operations = collect_operations(compiler_type, upload)
+    if not operations:
+        logger.error("Can't find any operation")
+        transaction.abort()
+        return False
+
+    factory = GRID_COMPILERS[compiler_type]
+    try:
+        compiler = factory(upload, operations)
+        grids = compiler.process_datas()
+        messages.append(compiler.get_message(grids))
+    except Exception as exc:
+        logger.exception("Error while generating measures")
+        transaction.abort()
+        message = getattr(exc, "message", str(exc))
+        send_error(
+            request,
+            mail_addresses,
+            factory.label,
+            message,
         )
-    return upload
+        return False
+    else:
+        logger.info("{0} measure grids were handled".format(len(grids)))
+        send_success(
+            request,
+            mail_addresses,
+            compiler.label,
+            compiler.get_message(grids),
+        )
+        logger.info("A success email has been sent to {0}".format(mail_addresses))
+
+    transaction.commit()
+    logger.info("The transaction has been commited")
+    return True
+
+
+LOCK_NAME = "measure_compute"
+
+
+def compile_measures(upload_id: int, grid_type: Optional[str] = None):
+    """Compile accounting measures related to upload id
+
+    :param grid_type: One of the available grid_type (income_statement,
+    treasury, balance_sheet)
+    """
+    logger.info(f"Compiling Accounting States for upload {upload_id}")
+    if is_locked(LOCK_NAME):
+        logger.error("Other task is running : Cancel")
+        return False
+
+    acquire_lock(LOCK_NAME)
+    try:
+        if grid_type is not None:
+            logger.info(f"  + Only compiling {grid_type} grids")
+            grid_types = [grid_type]
+        else:
+            grid_types = list(GRID_COMPILERS.keys())
+
+        for grid_type in grid_types:
+            run_compiler(grid_type, upload_id)
+    except Exception:
+        logger.exception("Erreur inconnue")
+
+    release_lock(LOCK_NAME)
+    return True
 
 
 @celery_app.task(bind=True)
@@ -883,55 +1171,10 @@ def compile_measures_task(self, upload_id, grid_type=None):
     """
     Celery task handling measures compilation
     """
-    logger.info("Launching the compile measure task for upload {0}".format(upload_id))
-
-    if grid_type is not None:
-        logger.info("Only compiling {} grids".format(grid_type))
-
-    transaction.begin()
-    upload = get_upload_from_id(upload_id)
-
-    operations = None
-    if grid_type == "treasury":
-        operations = _collect_operations(upload_id, upload.filetype, upload.date)
-    else:
-        # Pour l'instant _collect_operations ne concerne que les états de
-        # trésorerie, à terme quand nous voudrons présenter les comptes de
-        # résultat par exercice fiscal elle pourra être également utilisé
-        # pour les comptes de résultat.
-        operations = AccountingOperation.query().filter_by(upload_id=upload_id).all()
-
-    mail_addresses = get_recipients_addresses(self.request)
-    compiler_factories = get_measure_compilers(upload.filetype, grid_type)
-    messages = []
-    for compiler_factory in compiler_factories:
-        try:
-            compiler = compiler_factory(upload, operations)
-            grids = compiler.process_datas()
-            messages.append(compiler.get_message(grids))
-        except Exception as err:
-            logger.exception("Error while generating measures")
-            transaction.abort()
-            send_error(
-                self.request,
-                mail_addresses,
-                compiler.label,
-                err.message,
-            )
-            return False
-        else:
-            logger.info("{0} measure grids were handled".format(len(grids)))
-            send_success(
-                self.request,
-                mail_addresses,
-                compiler.label,
-                compiler.get_message(grids),
-            )
-            logger.info("A success email has been sent to {0}".format(mail_addresses))
-
-    transaction.commit()
-    logger.info("The transaction has been commited")
-    logger.info("* Task SUCCEEDED !!!")
+    logger.info("# Launching the compile measure task #")
+    res = compile_measures(upload_id, grid_type)
+    if res:
+        logger.info("===> Task Finished")
 
 
 @celery_app.task(bind=True)
@@ -947,7 +1190,7 @@ def scheduled_compile_measure_task(self, force=False):
         type = crontab
         schedule = {"minute": 0, "hour": 6}
     """
-    logger.info("Launching scheduled compile measure task for synchronized datas")
+    logger.info("# Launching scheduled compile measure task for synchronized datas #")
     yesterday = datetime.date.today() - datetime.timedelta(1)
     uploads = (
         AccountingOperationUpload.query()
@@ -960,54 +1203,11 @@ def scheduled_compile_measure_task(self, force=False):
         .all()
     )
     if not uploads:
-        logger.info(
+        logger.error(
             "ABORT : no upload with 'synchronized_accounting' type \
 since yesterday"
         )
     else:
         for upload in uploads:
-            transaction.begin()
-            logger.info("Compiling the measures for upload {} ...".format(upload.id))
-            upload_object = AccountingOperationUpload.get(upload.id)
-            measure_compiler_factories = [
-                TreasuryMeasureCompiler,
-                IncomeStatementMeasureCompiler,
-            ]
-            for measure_compiler_factory in measure_compiler_factories:
-                operations = None
-                if measure_compiler_factory == TreasuryMeasureCompiler:
-                    operations = _collect_operations(
-                        upload.id,
-                        upload_object.filetype,
-                        upload_object.date,
-                    )
-                else:
-                    operations = (
-                        AccountingOperation.query().filter_by(upload_id=upload.id).all()
-                    )
-                try:
-                    measure_compiler = measure_compiler_factory(
-                        upload_object, operations
-                    )
-                    measure_compiler.process_datas()
-                except Exception as err:
-                    transaction.abort()
-                    logger.exception("ERROR : {}".format(err))
-                    mail_addresses = get_recipients_addresses(self.request)
-                    if mail_addresses:
-                        send_error(
-                            self.request, mail_addresses, measure_compiler.label, err
-                        )
-                        logger.error(
-                            "An error mail has been sent to {}".format(mail_addresses)
-                        )
-                    logger.exception("Transaction has been rollbacked")
-                    return False
-            transaction.commit()
-            logger.info(
-                "SUCCESS : Measure computing transaction has been commited \
-                    for upload {}".format(
-                    upload.id
-                )
-            )
-        logger.info("End of scheduled compile measure task for synchronized datas")
+            compile_measures(upload.id)
+        logger.info("===> End of scheduled compile measure task for synchronized datas")
