@@ -15,7 +15,7 @@ import transaction
 import csv
 
 try:
-    from cStringIO import StringIO
+    from io import StringIO
 except ImportError:
     from io import StringIO
 from collections import OrderedDict
@@ -50,13 +50,13 @@ from endi_celery.models import (
 
 logger = log = utils.get_logger(__name__)
 
-MISSING_KEY_ERROR = u"Erreur : Le champ {0} ({1}) est requis mais n'a pas été \
+MISSING_KEY_ERROR = "Erreur : Le champ {0} ({1}) est requis mais n'a pas été \
 configuré à l'étape 2"
-MULTIPLE_ENTRY_ERROR = u"Pour une même valeur clé ({0}), plusieurs entrées \
+MULTIPLE_ENTRY_ERROR = "Pour une même valeur clé ({0}), plusieurs entrées \
 ont été détectées, nous ne sommes pas en mesure de mettre à jour ces données."
-NO_ENTRY_FOUND_ERROR = u"Aucune entrée n'a pu être retrouvée pour la clé {0} \
+NO_ENTRY_FOUND_ERROR = "Aucune entrée n'a pu être retrouvée pour la clé {0} \
 avec la valeur {1}"
-NO_ID_KEY_ERROR = u"Une entrée n'a pas de valeur pour la clé {0}."
+NO_ID_KEY_ERROR = "Une entrée n'a pas de valeur pour la clé {0}."
 UNFILLED_VALUES = ("", None, 0)
 
 BOOLEAN_FALSE = ("0", "false", "non", "", "False")
@@ -259,14 +259,14 @@ class CsvImportAssociator(BaseSqlaInspector):
                 continue
             result[header] = None
             toguess = header.replace("*", "").lower()
-            for column in self.columns.values():
+            for column in list(self.columns.values()):
                 name = column["name"].lower()
                 label = column["label"].lower()
                 if toguess in [name, label]:
                     result[header] = column["name"]
 
         if user_defined is not None:
-            for key, value in user_defined.items():
+            for key, value in list(user_defined.items()):
                 if key in result:
                     result[key] = value
 
@@ -281,9 +281,9 @@ class CsvImportAssociator(BaseSqlaInspector):
         """
         if association_dict is None:
             association_dict = self.association_dict
-        values = association_dict.values()
+        values = list(association_dict.values())
         if "id" not in values:
-            for column in self.columns.values():
+            for column in list(self.columns.values()):
                 if column.get("mandatory"):
                     if column["name"] not in values:
                         raise MissingMandatoryArgument(
@@ -313,7 +313,7 @@ class CsvImportAssociator(BaseSqlaInspector):
         """
         kwargs = {}
         unhandled = {}
-        for csv_key, value in csv_line.items():
+        for csv_key, value in list(csv_line.items()):
             value = ascii.force_unicode(value)
 
             if csv_key == "id":
@@ -448,7 +448,7 @@ class CsvImporter(object):
             "only_override",
         ):
             raise KeyError(
-                u"The action attr should be one of " '("insert", "update", "override")'
+                "The action attr should be one of " '("insert", "update", "override")'
             )
 
         if action == "insert":
@@ -481,11 +481,11 @@ class CsvImporter(object):
                 self.messages.append(message)
 
         if persist:
-            new_entry_msg = u"{0} nouvelles entrées ont été traitées"
-            update_entry_msg = u"{0} entrées existantes ont été traitées"
+            new_entry_msg = "{0} nouvelles entrées ont été traitées"
+            update_entry_msg = "{0} entrées existantes ont été traitées"
         else:
-            new_entry_msg = u"{0} nouvelles entrées seront créées"
-            update_entry_msg = u"{0} entrées existantes seront mises à jour"
+            new_entry_msg = "{0} nouvelles entrées seront créées"
+            update_entry_msg = "{0} entrées existantes seront mises à jour"
 
         self.messages.append(new_entry_msg.format(self.new_count))
         self.messages.append(update_entry_msg.format(self.update_count))
@@ -499,7 +499,7 @@ class CsvImporter(object):
         boolean saying if it's an update
         """
         logger.debug("Inserting (1) {}".format(args))
-        for key, value in self.default_init_values.items():
+        for key, value in list(self.default_init_values.items()):
             args[key] = value
 
         logger.debug("Inserting {}".format(args))
@@ -519,10 +519,10 @@ class CsvImporter(object):
         :returns: a tuple (model, updated_token) where updated_token is a
         boolean saying if it's an update
         """
-        logger.debug(u"Launching update")
-        logger.debug(u"Args :")
+        logger.debug("Launching update")
+        logger.debug("Args :")
         logger.debug(args)
-        logger.debug(u"Insert ? : %s" % insert)
+        logger.debug("Insert ? : %s" % insert)
         identification_value = args.pop(self.id_key, None)
         updated = False
 
@@ -547,15 +547,15 @@ class CsvImporter(object):
                     .one()
                 )
 
-                for key, value in self.default_init_values.items():
+                for key, value in list(self.default_init_values.items()):
                     if getattr(model, key) != value:
-                        log.warn(u"POSSIBLE BREAK IN ATTEMPT")
-                        log.warn(u"Importation process, default values :")
+                        log.warn("POSSIBLE BREAK IN ATTEMPT")
+                        log.warn("Importation process, default values :")
                         log.warn(self.default_init_values)
                         log.warn("The model they try to edit : %s" % model.id)
-                        raise Exception(u"POSSIBLE BREAK IN ATTEMPT !!!!!!")
+                        raise Exception("POSSIBLE BREAK IN ATTEMPT !!!!!!")
 
-                for key, value in args.items():
+                for key, value in list(args.items()):
                     if getattr(model, key) in UNFILLED_VALUES or override:
                         setattr(model, key, value)
                 if persist:
@@ -642,7 +642,7 @@ class CsvImporter(object):
         )
 
         function = getattr(self, "_{0}".format(self.action))
-        logger.debug(u"The function we use : %s" % function)
+        logger.debug("The function we use : %s" % function)
         # Here we should handle edition
         try:
             model, updated = function(args, persist=persist)
@@ -672,7 +672,7 @@ class CsvImporter(object):
             import traceback
 
             traceback.print_exc()
-            log.exception(u"Erreur lors de l'import de données")
+            log.exception("Erreur lors de l'import de données")
             self.in_error_lines.append(line)
             res = None
             message = e.message
@@ -690,7 +690,7 @@ class CsvImporter(object):
             result = ""
         else:
             buf = StringIO()
-            fieldnames = [key for key in datas[0].keys() if key != ""]
+            fieldnames = [key for key in list(datas[0].keys()) if key != ""]
             writer = csv.DictWriter(
                 buf,
                 fieldnames,
@@ -795,13 +795,13 @@ def async_import_datas(
     :param delimiter: The delimiter to use for csv parsing
     :param quotechar: The quotechar to use for csv parsing
     """
-    logger.info(u"We are launching an asynchronous csv import")
-    logger.info(u"  The job id : %s" % job_id)
-    logger.info(u"  The csv_filepath : %s" % csv_filepath)
-    logger.info(u"  The association dict : %s" % association_dict)
-    logger.info(u"  The id key : %s" % id_key)
-    logger.info(u"  Action : %s" % action)
-    logger.info(u"  Default initialization values : %s" % default_values)
+    logger.info("We are launching an asynchronous csv import")
+    logger.info("  The job id : %s" % job_id)
+    logger.info("  The csv_filepath : %s" % csv_filepath)
+    logger.info("  The association dict : %s" % association_dict)
+    logger.info("  The id key : %s" % id_key)
+    logger.info("  Action : %s" % action)
+    logger.info("  Default initialization values : %s" % default_values)
 
     utils.start_job(self.request, CsvImportJob, job_id)
 
@@ -823,14 +823,14 @@ def async_import_datas(
             delimiter=delimiter,
             quotechar=quotechar,
         )
-        logger.info(u"Importing the datas")
+        logger.info("Importing the datas")
         importer.import_datas()
         transaction.commit()
     except Exception as e:
         transaction.abort()
-        logger.exception(u"The transaction has been aborted")
+        logger.exception("The transaction has been aborted")
         utils.record_failure(CsvImportJob, job_id, [e])
     else:
-        logger.info(u"We update the job informations")
+        logger.info("We update the job informations")
         utils.record_completed(CsvImportJob, job_id, **importer.log())
     return ""
